==> flutter_widget_from_html-0.4.0-rc.2020043001.tar.gz: test/issue_23_test.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';

import '_.dart';

const html = 'Above\n<blockquote>Foo</blockquote>\nBelow';

class BlockquoteWebViewScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) => Scaffold(
        appBar: AppBar(
          title: Text('BlockquoteWebViewScreen'),
        ),
        body: ListView(children: <Widget>[
          HtmlWidget(
            html,
            factoryBuilder: (config) => _BlockquoteWebViewWf(config),
            key: hwKey,
          ),
        ]),
      );
}

class _BlockquoteWebViewWf extends WidgetFactory {
  final blockquoteOp = BuildOp(
    onWidgets: (meta, _) => [
      WebView(
        Uri.dataFromString(
          meta.domElement.innerHtml,
          mimeType: 'text/html',
          encoding: Encoding.getByName('utf-8'),
        ).toString(),
        aspectRatio: 16 / 9,
        getDimensions: true,
      )
    ],
  );

  _BlockquoteWebViewWf(HtmlConfig config) : super(config);

  @override
  void parseTag(NodeMetadata meta, String tag, Map<dynamic, String> attrs) {
    if (tag == 'blockquote') {
      meta.op = blockquoteOp;
      return;
    }

    return super.parseTag(meta, tag, attrs);
  }
}

void main() {
  testWidgets('renders BLOCKQUOTE as web view', (WidgetTester tester) async {
    final explained = await explain(
      tester,
      null,
      hw: HtmlWidget(
        html,
        bodyPadding: const EdgeInsets.all(0),
        factoryBuilder: (hw) => _BlockquoteWebViewWf(hw),
        key: hwKey,
      ),
    );
    expect(
        explained,
        equals('[Column:children=[RichText:(:Above)],'
            '[WebView:url=data:text/html;charset=utf-8,Foo,aspectRatio=1.78,getDimensions=1,js=1],'
            '[RichText:(:Below)]]'));
  });
}

==> flutter_widget_from_html-0.4.1-rc.2020052701.tar.gz: test/issue_23_test.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';

import '_.dart';

const html = 'Above\n<blockquote>Foo</blockquote>\nBelow';

class BlockquoteWebViewScreen extends StatelessWidget {
  @override
  Widget build(BuildContext context) => Scaffold(
        appBar: AppBar(
          title: Text('BlockquoteWebViewScreen'),
        ),
        body: ListView(children: <Widget>[
          HtmlWidget(
            html,
            factoryBuilder: () => _BlockquoteWebViewWf(),
            key: hwKey,
          ),
        ]),
      );
}

class _BlockquoteWebViewWf extends WidgetFactory {
  final blockquoteOp = BuildOp(
    onWidgets: (meta, _) => [
      WebView(
        Uri.dataFromString(
          meta.domElement.innerHtml,
          mimeType: 'text/html',
          encoding: Encoding.getByName('utf-8'),
        ).toString(),
        aspectRatio: 16 / 9,
        getDimensions: true,
      )
    ],
  );

  @override
  void parseTag(NodeMetadata meta, String tag, Map<dynamic, String> attrs) {
    if (tag == 'blockquote') {
      meta.op = blockquoteOp;
      return;
    }

    return super.parseTag(meta, tag, attrs);
  }
}

void main() {
  testWidgets('renders BLOCKQUOTE as web view', (WidgetTester tester) async {
    final explained = await explain(
      tester,
      null,
      hw: HtmlWidget(
        html,
        bodyPadding: const EdgeInsets.all(0),
        factoryBuilder: () => _BlockquoteWebViewWf(),
        key: hwKey,
      ),
    );
    expect(
        explained,
        equals('[Column:children=[RichText:(:Above)],'
            '[WebView:url=data:text/html;charset=utf-8,Foo,aspectRatio=1.78,getDimensions=1,js=1],'
            '[RichText:(:Below)]]'));
  });
}
